You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mxnet.apache.org by zh...@apache.org on 2021/09/14 05:31:51 UTC

[incubator-mxnet] branch master updated: [Website] Fix website publish (#20573)

This is an automated email from the ASF dual-hosted git repository.

zhenghuijin pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-mxnet.git


The following commit(s) were added to refs/heads/master by this push:
     new 98e6b36  [Website] Fix website publish (#20573)
98e6b36 is described below

commit 98e6b36ebb45d6e094f05258648d7cdc04242862
Author: Zhenghui Jin <69...@users.noreply.github.com>
AuthorDate: Mon Sep 13 22:29:34 2021 -0700

    [Website] Fix website publish (#20573)
    
    * fix website publish
    
    * update
    
    * remove .asf.yaml from version/master
    
    * force include .asf.yaml
    
    * include .htaccess
    
    * add .asf.yaml check in CI
---
 ci/docker/runtime_functions.sh        | 7 ++++++-
 docs/static_site/src/.asf.yaml        | 2 ++
 docs/static_site/src/_config_prod.yml | 6 ++++++
 3 files changed, 14 insertions(+), 1 deletion(-)

diff --git a/docs/static_site/src/.asf.yaml b/docs/static_site/src/.asf.yaml
new file mode 100644
index 0000000..0735550
--- /dev/null
+++ b/docs/static_site/src/.asf.yaml
@@ -0,0 +1,2 @@
+publish:
+  whoami: asf-site
diff --git a/docs/static_site/src/_config_prod.yml b/docs/static_site/src/_config_prod.yml
index a2a2036..0139f9e 100644
--- a/docs/static_site/src/_config_prod.yml
+++ b/docs/static_site/src/_config_prod.yml
@@ -59,6 +59,12 @@ markdown: kramdown
 plugins:
   - jekyll-feed
   - jekyll-seo-tag
+
+# Force include .asf.yaml
+include:
+  - .asf.yaml
+  - .htaccess
+
 # Exclude from processing.
 # The following items will not be processed, by default. Create a custom list
 # to override the default setting.
diff --git a/ci/docker/runtime_functions.sh b/ci/docker/runtime_functions.sh
index a623bfd..3d33da2 100755
--- a/ci/docker/runtime_functions.sh
+++ b/ci/docker/runtime_functions.sh
@@ -1204,7 +1204,12 @@ build_docs() {
     mkdir -p $python_doc_folder && tar -xzf python-artifacts.tgz --directory $python_doc_folder
     mkdir -p $api_folder/cpp/docs/api && tar -xzf c-artifacts.tgz --directory $api_folder/cpp/docs/api
 
-     # check if .htaccess file exists
+    # check if .asf.yaml file exists
+    if [ ! -f "html/.asf.yaml" ]; then
+        echo "html/.asf.yaml file does not exist. Exiting 1"
+        exit 1
+    fi
+    # check if .htaccess file exists
     if [ ! -f "html/.htaccess" ]; then
         echo "html/.htaccess file does not exist. Exiting 1"
         exit 1